==> dagster_cron-0.6.0rc1.tar.gz: dagster_cron-0.6.0rc1/setup.py <==
import argparse
import sys

from setuptools import find_packages, setup


def get_version(name):
    version = {}
    with open('dagster_cron/version.py') as fp:
        exec(fp.read(), version)  # pylint: disable=W0122

    if name == 'dagster-cron':
        return version['__version__']
    elif name == 'dagster-cron-nightly':
        return version['__nightly__']
    else:
        raise Exception('Shouldn\'t be here: bad package name {name}'.format(name=name))


parser = argparse.ArgumentParser()
parser.add_argument('--nightly', action='store_true')


def _do_setup(name='dagster-cron'):
    setup(
        name='dagster_cron',
        version=get_version(name),
        author='Elementl',
        license='Apache-2.0',
        description='A Dagster integration for cron',
        url='https://github.com/dagster-io/dagster/tree/master/python_modules/libraries/dagster-cron',
        classifiers=[
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'License :: OSI Approved :: Apache Software License',
            'Operating System :: OS Independent',
        ],
        packages=find_packages(exclude=['test']),
        install_requires=['dagster', "python-crontab>=2.3.8"],
        tests_require=['mock==2.0.*'],
        zip_safe=False,
    )


if __name__ == '__main__':
    parsed, unparsed = parser.parse_known_args()
    sys.argv = [sys.argv[0]] + unparsed
    if parsed.nightly:
        _do_setup('dagster-cron-nightly')
    else:
        _do_setup('dagster-cron')

==> dagster_cron-0.6.5.tar.gz: dagster_cron-0.6.5/setup.py <==
import argparse
import sys

from setuptools import find_packages, setup


def get_version(name):
    version = {}
    with open('dagster_cron/version.py') as fp:
        exec(fp.read(), version)  # pylint: disable=W0122

    if name == 'dagster-cron':
        return version['__version__']
    elif name == 'dagster-cron-nightly':
        return version['__nightly__']
    else:
        raise Exception('Shouldn\'t be here: bad package name {name}'.format(name=name))


parser = argparse.ArgumentParser()
parser.add_argument('--nightly', action='store_true')


def _do_setup(name='dagster-cron'):
    setup(
        name='dagster_cron',
        version=get_version(name),
        author='Elementl',
        license='Apache-2.0',
        description='A Dagster integration for cron',
        url='https://github.com/dagster-io/dagster/tree/master/python_modules/libraries/dagster-cron',
        classifiers=[
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'License :: OSI Approved :: Apache Software License',
            'Operating System :: OS Independent',
        ],
        packages=find_packages(exclude=['test']),
        install_requires=['dagster', "python-crontab>=2.3.8"],
        tests_require=['mock'],
        zip_safe=False,
    )


if __name__ == '__main__':
    parsed, unparsed = parser.parse_known_args()
    sys.argv = [sys.argv[0]] + unparsed
    if parsed.nightly:
        _do_setup('dagster-cron-nightly')
    else:
        _do_setup('dagster-cron')
